#[with_fixtures]Expand description
Runs a function with setup and teardown fixtures from the current module
Example:
use fluent_test::prelude::*;
#[with_fixtures]
fn test_something() {
// Test code here
expect!(2 + 2).to_equal(4);
}#[with_fixtures]Runs a function with setup and teardown fixtures from the current module
Example:
use fluent_test::prelude::*;
#[with_fixtures]
fn test_something() {
// Test code here
expect!(2 + 2).to_equal(4);
}