Module fixtures

Module fixtures 

Module for test fixtures support with setup and teardown capabilities

This module provides the runtime functionality for test fixtures using attributes. It works with procedural macros to provide a clean API for setting up and tearing down test environments.

Functions

is_in_fixture_test
Check if we’re running inside a fixture-wrapped test
register_after_all
Register an after_all function for a module
register_before_all
Register a before_all function for a module
register_setup
Register a setup function for a module
register_teardown
Register a teardown function for a module
run_test_with_fixtures
Run a test function with appropriate setup and teardown

Type Aliases

FixtureFunc
Simple fixture registration system that uses a global hashmap instead of inventory