pub fn initialize()Expand description
Initialize the FluentTest system This is called automatically when needed but can also be called explicitly
pub fn initialize()Initialize the FluentTest system This is called automatically when needed but can also be called explicitly