pub struct ConsoleRenderer { /* private fields */ }Expand description
Handles rendering of test results to the console
Implementations
Sourceimpl ConsoleRenderer
impl ConsoleRenderer
Sourcepub fn render_success(&self, result: &Assertion<()>) -> String
pub fn render_success(&self, result: &Assertion<()>) -> String
Render a successful assertion result
Sourcepub fn render_failure(&self, result: &Assertion<()>) -> (String, String)
pub fn render_failure(&self, result: &Assertion<()>) -> (String, String)
Render a failed assertion result
Sourcepub fn render_session_summary(&self, result: &TestSessionResult) -> String
pub fn render_session_summary(&self, result: &TestSessionResult) -> String
Render a full test session result
Sourcepub fn print_success(&self, result: &Assertion<()>)
pub fn print_success(&self, result: &Assertion<()>)
Format and print a successful test result to the console
Sourcepub fn print_failure(&self, result: &Assertion<()>)
pub fn print_failure(&self, result: &Assertion<()>)
Format and print a failed test result to the console
Sourcepub fn print_session_summary(&self, result: &TestSessionResult)
pub fn print_session_summary(&self, result: &TestSessionResult)
Print the complete test session summary