macro_rules! fluent_test {
() => { ... };
}Expand description
Run all FluentTest tests in a module
This can be used as a test harness to handle initialization and reporting.
macro_rules! fluent_test {
() => { ... };
}Run all FluentTest tests in a module
This can be used as a test harness to handle initialization and reporting.