Module for test fixtures support with setup and teardown capabilities
This module provides the runtime functionality for test fixtures using attributes. It works with procedural macros to provide a clean API for setting up and tearing down test environments.
Functions
- is_
in_ fixture_ test - Check if we’re running inside a fixture-wrapped test
- register_
after_ all - Register an after_all function for a module
- register_
before_ all - Register a before_all function for a module
- register_
setup - Register a setup function for a module
- register_
teardown - Register a teardown function for a module
- run_
test_ with_ fixtures - Run a test function with appropriate setup and teardown
Type Aliases
- Fixture
Func - Simple fixture registration system that uses a global hashmap instead of inventory