Module config

Structs

Config
Configuration for FluentTest’s output and behavior

Functions

initialize
Initialize the FluentTest system This is called automatically when needed but can also be called explicitly
is_enhanced_output_enabled
Check if enhanced output is enabled in the current configuration