pub struct Reporter;Implementations
Sourceimpl Reporter
impl Reporter
Sourcepub fn reset_message_cache()
pub fn reset_message_cache()
Clear the message cache to allow duplicated messages in different test scopes
Sourcepub fn enable_deduplication()
pub fn enable_deduplication()
Enable deduplication of messages
Sourcepub fn disable_deduplication()
pub fn disable_deduplication()
Disable deduplication of messages (for tests)
Sourcepub fn enable_silent_mode()
pub fn enable_silent_mode()
Enable silent mode to suppress intermediate output in chains
Sourcepub fn disable_silent_mode()
pub fn disable_silent_mode()
Disable silent mode to show all output
pub fn summarize()